@@ -1,4 +1,4 @@
-# Copyright 2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+# Copyright 2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License"). You
 # may not use this file except in compliance with the License. A copy of
@@ -11,12 +11,12 @@
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
 
-from ..core.abstractcontroller import AbstractBaseController
-from ..resources.strings import strings, flag_text, prompts
-from ..core import io
-from ..objects.exceptions import NotSupportedError
-from ..lib import utils
-from ..operations import commonops, swapops
+from ebcli.core.abstractcontroller import AbstractBaseController
+from ebcli.resources.strings import strings, flag_text, prompts
+from ebcli.core import io
+from ebcli.objects.exceptions import NotSupportedError
+from ebcli.lib import elasticbeanstalk, utils
+from ebcli.operations import swapops
 
 
 class SwapController(AbstractBaseController):
@@ -36,18 +36,14 @@ class SwapController(AbstractBaseController):
         destination_env = self.app.pargs.destination_name
 
         if not destination_env:
-            # Ask interactively for an env to swap with
-            envs = commonops.get_env_names(app_name)
+            envs = elasticbeanstalk.get_environment_names(app_name)
             if len(envs) < 2:
                 raise NotSupportedError(strings['swap.unsupported'])
 
-            # Filter out current env
             envs = [e for e in envs if e != source_env]
             if len(envs) == 1:
-                # Don't ask for env, just swap with only other environment
                 destination_env = envs[0]
             else:
-                # Ask for env to swap with
                 io.echo()
                 io.echo(prompts['swap.envprompt'])
                 destination_env = utils.prompt_for_item_in_list(envs)
