@@ -1,4 +1,4 @@
-# Copyright 2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+# Copyright 2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License"). You
 # may not use this file except in compliance with the License. A copy of
@@ -17,9 +17,9 @@ from cement.ext.ext_logging import LoggingLogHandler
 from cement.utils.misc import minimal_logger
 
 from ebcli import __version__
-from ..core import fileoperations
-from ..lib import aws
-from ..operations import commonops
+from ebcli.core import fileoperations
+from ebcli.lib import aws
+from ebcli.operations import commonops
 
 
 LOG = minimal_logger(__name__)
